@@ -32,7 +32,7 @@
 
 #ifndef lint
 static char ocopyright[] =
-"$Id: dhclient.c,v 1.129.2.32 2006/04/27 21:38:29 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium.  All rights reserved.\n";
+"$Id: dhclient.c,v 1.129.2.34 2006/08/22 15:13:57 dhankins Exp $ Copyright (c) 2004-2006 Internet Systems Consortium.  All rights reserved.\n";
 #endif /* not lint */
 
 #include "dhcpd.h"
@@ -1334,12 +1334,33 @@ void dhcpnak (packet)
 		return;
 	}
 
+	/* If we get a DHCPNAK, we use the EXPIRE dhclient-script state
+	 * to indicate that we want all old bindings to be removed.  (It
+	 * is possible that we may get a NAK while in the RENEW state,
+	 * so we might have bindings active at that time)
+	 */
+	script_init(client, "EXPIRE", NULL);
+	script_write_params(client, "old_", client->active);
+	if (client->alias)
+		script_write_params(client, "alias_", client->alias);
+	script_go(client);
+
 	destroy_client_lease (client -> active);
 	client -> active = (struct client_lease *)0;
 
 	/* Stop sending DHCPREQUEST packets... */
 	cancel_timeout (send_request, client);
 
+	/* On some scripts, 'EXPIRE' causes the interface to be ifconfig'd
+	 * down (this expunges any routes and arp cache).  This makes the
+	 * interface unusable by state_init(), which we call next.  So, we
+	 * need to 'PREINIT' the interface to bring it back up.
+	 */
+	script_init(client, "PREINIT", NULL);
+	if (client->alias)
+		script_write_params(client, "alias_", client->alias);
+	script_go(client);
+
 	client -> state = S_INIT;
 	state_init (client);
 }
